An implementation of z-curves - a method for estimating expected discovery and replicability rates on the bases of test-statistics of published studies. The package provides functions for fitting the density, EM, and censored EM version (Bartoš & Schimmack, 2022, tools:::Rd_expr_doi("10.15626/MP.2021.2720"); Schimmack & Bartoš, 2023, tools:::Rd_expr_doi(" 10.1371/journal.pone.0290084")), as well as the original density z-curve (Brunner & Schimmack, 2020, tools:::Rd_expr_doi("10.15626/MP.2018.874")). Furthermore, the package provides summarizing and plotting functions for the fitted z-curve objects. See the aforementioned articles for more information about the z-curves, expected discovery and replicability rates, validation studies, and limitations.
Maintainer: František Bartoš f.bartos96@gmail.com
Authors:
Ulrich Schimmack ulrich.schimmack@utoronto.ca
Useful links: